<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "La data de venciment és en el passat.",
"Couldn't send mail to following users: %s " => "No s'ha pogut enviar correu als usuaris següents: %s",
"Turned on maintenance mode" => "Activat el mode de manteniment",
"Turned off maintenance mode" => "Desactivat el mode de manteniment",
"Updated database" => "Actualitzada la base de dades",
"Checked database schema update" => "S'ha comprobat l'actualització de l'esquema de la base de dades",
"Disabled incompatible apps: %s" => "Aplicacions incompatibles desactivades: %s",
"No image or file provided" => "No s'han proporcionat imatges o fitxers",
"Unknown filetype" => "Tipus de fitxer desconegut",
"Invalid image" => "Imatge no vàlida",
"No temporary profile picture available, try again" => "No hi ha imatge temporal de perfil disponible, torneu a intentar-ho",
"No crop data provided" => "No heu proporcionat dades del retall",
"Sunday" => "Diumenge",
"Monday" => "Dilluns",
"Tuesday" => "Dimarts",
"Wednesday" => "Dimecres",
"Thursday" => "Dijous",
"Friday" => "Divendres",
"Saturday" => "Dissabte",
"January" => "Gener",
"February" => "Febrer",
"March" => "Març",
"April" => "Abril",
"May" => "Maig",
"June" => "Juny",
"July" => "Juliol",
"August" => "Agost",
"September" => "Setembre",
"October" => "Octubre",
"November" => "Novembre",
"December" => "Desembre",
"Settings" => "Configuració",
"File" => "Fitxer",
"Folder" => "Carpeta",
"Image" => "Imatge",
"Audio" => "Audio",
"Saving..." => "Desant...",
"seconds ago" => "segons enrere",
"_%n minute ago_::_%n minutes ago_" => array("fa %n minut","fa %n minuts"),
"_%n hour ago_::_%n hours ago_" => array("fa %n hora","fa %n hores"),
"today" => "avui",
"yesterday" => "ahir",
"_%n day ago_::_%n days ago_" => array("fa %n dies","fa %n dies"),
"last month" => "el mes passat",
"_%n month ago_::_%n months ago_" => array("fa %n mes","fa %n mesos"),
"last year" => "l'any passat",
"years ago" => "anys enrere",
"Couldn't send reset email. Please contact your administrator." => "No s'ha pogut restablir el correu. Contacteu amb l'administrador.",
"The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." => "L'enllaç per reiniciar la vostra contrasenya s'ha enviat al vostre correu. Si no el rebeu en un temps raonable comproveu les carpetes de spam. <br>Si no és allà, pregunteu a l'administrador local.",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" => "Els vostres fitxers estan encriptats. Si no heu habilitat la clau de recuperació no hi haurà manera de recuperar les dades després que reestabliu la contrasenya. <br />Si sabeu què fer, contacteu amb l'administrador abans de continuar.<br />Voleu continuar?",
"I know what I'm doing" => "Sé el que faig",
"Reset password" => "Reinicialitza la contrasenya",
"Password can not be changed. Please contact your administrator." => "La contrasenya no es pot canviar. Contacteu amb l'administrador.",
"Yes" => "Sí",
"No" => "No",
"Choose" => "Escull",
"Error loading file picker template: {error}" => "Error en carregar la plantilla de càrrega de fitxers: {error}",
"Ok" => "D'acord",
"Error loading message template: {error}" => "Error en carregar la plantilla de missatge: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} conflicte de fitxer","{count} conflictes de fitxer"),
"One file conflict" => "Un fitxer en conflicte",
"New Files" => "Fitxers nous",
"Already existing files" => "Fitxers que ja existeixen",
"Which files do you want to keep?" => "Quin fitxer voleu conservar?",
"If you select both versions, the copied file will have a number added to its name." => "Si seleccioneu les dues versions, el fitxer copiat tindrà un número afegit al seu nom.",
"Cancel" => "Cancel·la",
"Continue" => "Continua",
"(all selected)" => "(selecciona-ho tot)",
"({count} selected)" => "({count} seleccionats)",
"Error loading file exists template" => "Error en carregar la plantilla de fitxer existent",
"Very weak password" => "Contrasenya massa feble",
"Weak password" => "Contrasenya feble",
"So-so password" => "Contrasenya passable",
"Good password" => "Contrasenya bona",
"Strong password" => "Contrasenya forta",
"Shared" => "Compartit",
"Shared by {owner}" => "Compartits per {owner}",
"Shared with {recipients}" => "Compartit amb {recipients}",
"Share" => "Comparteix",
"Error" => "Error",
"Error while sharing" => "Error en compartir",
"Error while unsharing" => "Error en deixar de compartir",
"Error while changing permissions" => "Error en canviar els permisos",
"Shared with you and the group {group} by {owner}" => "Compartit amb vos i amb el grup {group} per {owner}",
"Shared with you by {owner}" => "Compartit amb vos per {owner}",
"Share with user or group …" => "Comparteix amb usuari o grup...",
"Share link" => "Enllaç de compartició",
"The public link will expire no later than {days} days after it is created" => "L'enllaç públic tindrà venciment abans de {days} dies després de crear-lo",
"By default the public link will expire after {days} days" => "Per defecte l'enllaç públic té venciment en {days} dies",
"Password protect" => "Protegir amb contrasenya",
"Choose a password for the public link" => "Escolliu una contrasenya per l'enllaç públic",
"Allow Public Upload" => "Permet pujada pública",
"Email link to person" => "Enllaç per correu electrónic amb la persona",
"Send" => "Envia",
"Set expiration date" => "Estableix la data de venciment",
"Expiration date" => "Data de venciment",
"Share via email:" => "Comparteix per correu electrònic",
"No people found" => "No s'ha trobat ningú",
"group" => "grup",
"Resharing is not allowed" => "No es permet compartir de nou",
"Shared in {item} with {user}" => "Compartit en {item} amb {user}",
"Unshare" => "Deixa de compartir",
"notify by email" => "notifica per correu electrònic",
"can share" => "pot compartir",
"can edit" => "pot editar",
"access control" => "control d'accés",
"create" => "crea",
"update" => "actualitza",
"delete" => "elimina",
"Password protected" => "Protegeix amb contrasenya",
"Error unsetting expiration date" => "Error en eliminar la data de venciment",
"Error setting expiration date" => "Error en establir la data de venciment",
"Sending ..." => "Enviant...",
"Email sent" => "El correu electrónic s'ha enviat",
"Warning" => "Avís",
"The object type is not specified." => "No s'ha especificat el tipus d'objecte.",
"Enter new" => "Escriu nou",
"Delete" => "Esborra",
"Add" => "Afegeix",
"Edit tags" => "Edita etiquetes",
"Error loading dialog template: {error}" => "Error en carregar la plantilla de diàleg: {error}",
"No tags selected for deletion." => "No heu seleccionat les etiquetes a eliminar.",
"Updating {productName} to version {version}, this may take a while." => "Actualitzant {productName} a la versió {version}. Pot trigar una estona.",
"Please reload the page." => "Carregueu la pàgina de nou.",
"The update was unsuccessful." => "L'actualització no ha tingut èxit.",
"The update was successful. Redirecting you to ownCloud now." => "L'actualització ha estat correcte. Ara us redirigim a ownCloud.",
"Couldn't reset password because the token is invalid" => "No es pot restablir la contrasenya perquè el testimoni no és vàlid",
"Couldn't send reset email. Please make sure your username is correct." => "No s'ha pogut enviar el correu de restabliment. Assegureu-vos que el vostre nom d'usuari és correcte.",
"Couldn't send reset email because there is no email address for this username. Please contact your administrator." => "No s'ha pogut enviar el correu de restabliment perquè no hi ha cap correu electrònic per aquest usuari. Contacteu amb l'administrador.",
"%s password reset" => "restableix la contrasenya %s",
"Use the following link to reset your password: {link}" => "Useu l'enllaç següent per restablir la contrasenya: {link}",
"You will receive a link to reset your password via Email." => "Rebreu un enllaç al correu electrònic per reiniciar la contrasenya.",
"Username" => "Nom d'usuari",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Els vostres fitxers estan encriptats. Si no heu habilitat la clau de recuperació no hi haurà manera de recuperar les dades després que reestabliu la contrasenya. Si sabeu què fer, contacteu amb l'administrador abans de continuar. Voleu continuar?",
"Yes, I really want to reset my password now" => "Sí, vull restablir ara la contrasenya",
"Reset" => "Estableix de nou",
"New password" => "Contrasenya nova",
"New Password" => "Contrasenya nova",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Mac OS X no té suport i %s no funcionarà correctament en aquesta plataforma. Useu-ho al vostre risc!",
"For the best results, please consider using a GNU/Linux server instead." => "Per millors resultats, millor considereu utilitzar un servidor GNU/Linux.",
"Personal" => "Personal",
"Users" => "Usuaris",
"Apps" => "Aplicacions",
"Admin" => "Administració",
"Help" => "Ajuda",
"Error loading tags" => "Error en carregar les etiquetes",
"Tag already exists" => "L'etiqueta ja existeix",
"Error deleting tag(s)" => "Error en eliminar etiqueta(s)",
"Error tagging" => "Error en etiquetar",
"Error untagging" => "Error en treure les etiquetes",
"Error favoriting" => "Error en posar a preferits",
"Error unfavoriting" => "Error en treure de preferits",
"Access forbidden" => "Accés prohibit",
"Cloud not found" => "No s'ha trobat el núvol",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Ei,\n\nnomés fer-te saber que %s ha compartit %s amb tu.\nMira-ho a: %s\n\n",
"The share will expire on %s." => "La compartició venç el %s.",
"Cheers!" => "Salut!",
"Security Warning" => "Avís de seguretat",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "La versió de PHP que useu és vulnerable a l'atac per NULL Byte (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Actualitzeu la instal·lació de PHP per usar %s de forma segura.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "No està disponible el generador de nombres aleatoris segurs, habiliteu l'extensió de PHP OpenSSL.",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Sense un generador de nombres aleatoris segurs un atacant podria predir els senyals per restablir la contrasenya i prendre-us el compte.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "La carpeta de dades i els seus fitxers probablement són accessibles des d'internet perquè el fitxer .htaccess no funciona.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "Per informació de com configurar el servidor, comproveu la <a href=\"%s\" target=\"_blank\">documentació</a>.",
"Create an <strong>admin account</strong>" => "Crea un <strong>compte d'administrador</strong>",
"Password" => "Contrasenya",
"Storage & database" => "Emmagatzematge i base de dades",
"Data folder" => "Carpeta de dades",
"Configure the database" => "Configura la base de dades",
"Only %s is available." => "Només hi ha disponible %s",
"Database user" => "Usuari de la base de dades",
"Database password" => "Contrasenya de la base de dades",
"Database name" => "Nom de la base de dades",
"Database tablespace" => "Espai de taula de la base de dades",
"Database host" => "Ordinador central de la base de dades",
"SQLite will be used as database. For larger installations we recommend to change this." => "S'utilitzarà SQLite com a base de dades. Per instal·lacions grans recomanem que la canvieu.",
"Finish setup" => "Acaba la configuració",
"Finishing …" => "Acabant...",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "Aquesta aplicació necessita tenir JavaScript activat per funcionar correctament. <a href=\"http://enable-javascript.com/\" target=\"_blank\">Activeu JavaScript</a> i carregueu aquesta interfície de nou.",
"%s is available. Get more information on how to update." => "%s està disponible. Obtingueu més informació de com actualitzar.",
"Log out" => "Surt",
"Automatic logon rejected!" => "Inici de sessió automàtic rebutjat!",
"If you did not change your password recently, your account may be compromised!" => "Si no heu canviat la contrasenya recentment el vostre compte pot estar compromès!",
"Please change your password to secure your account again." => "Canvieu la contrasenya de nou per assegurar el vostre compte.",
"Server side authentication failed!" => "L'autenticació del servidor ha fallat!",
"Please contact your administrator." => "Contacteu amb l'administrador.",
"Forgot your password? Reset it!" => "Heu oblidat la contrasenya? Restabliu-la!",
"remember" => "recorda'm",
"Log in" => "Inici de sessió",
"Alternative Logins" => "Acreditacions alternatives",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Ei, <br><br>només fer-vos saber que %s us ha comparti <strong>%s</strong>. <br><a href=\"%s\">Mireu-ho!</a>",
"This ownCloud instance is currently in single user mode." => "La instància ownCloud està en mode d'usuari únic.",
"This means only administrators can use the instance." => "Això significa que només els administradors poden usar la instància.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Contacteu amb l'administrador del sistema si aquest missatge persisteix o apareix inesperadament.",
"Thank you for your patience." => "Gràcies per la paciència.",
"%s will be updated to version %s." => "%s s'actualitzarà a la versió %s.",
"The following apps will be disabled:" => "Les següents aplicacions es desactivaran:",
"The theme %s has been disabled." => "S'ha desactivat el tema %s",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "Assegureu-vos que heu fet una còpia de seguretat de la base de dades, del fitxer de configuració i de la carpeta de dades abans de continuar.",
"Start update" => "Inicia l'actualització",
"This ownCloud instance is currently being updated, which may take a while." => "Aquesta instància d'ownCloud s'està actualitzant i podria trigar una estona.",
"Please reload this page after a short time to continue using ownCloud." => "Carregueu de nou aquesta pàgina d'aquí a poc temps per continuar usant ownCloud.",
"To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" => "Per evitar que s'esgoti el temps d'espera en instalacions grans, pots en el seu lloc fer córrer la següent comanda en el directori d'instalació."
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
